# AkariBot WebUI

This project is a WebUI panel for [AkariBot](https://github.com/Teahouse-Studios/akari-bot).

## Setup

```
yarn install
```

### Compiles and hot-reloads for development

```
yarn dev
```

### Compiles and minifies for production

```
yarn build
```

## Localization

Unfortunately, the free account of Crowdin cannot create a second integration, and the premium account is too expensive for me to afford :(

If there is a localization problem with the WebUI, please raise an issue.

Do not raise localization issues of AkariBot here, you should go to [Crowdin](https://crowdin.com/project/akari-bot).
